//
// Programmer:    Craig Stuart Sapp <craig@ccrma.stanford.edu>
// Creation Date: Wed Jan 23 21:10:32 PST 2002
// Last Modified: Wed Jan 23 21:10:35 PST 2002
// Filename:      ...soundio/multi2mono.cpp
// Syntax:        C++ 
//
// Description:   Adds all channels in the input sound file and writes
//                a sound file with the summation of all channels.
//                Amplitude scaling factor can be given to prevent
//                clipping if necessary.
//

#include "soundio.h"
#include <stdlib.h>
#include <iostream.h>


int main(int argc, char** argv) {
   Options options;
   options.define("a|amp=d:1.0",     "amplitude scaling factor");
   options.process(argc, argv);
   
   double amp = options.getDouble("amp");
   const char* inputname  = options.getArg(1);
   const char* outputname = options.getArg(2);

   SoundFileRead  insound(inputname);
   SoundHeader    header = insound;
   header.setChannels(1);
   SoundFileWrite outsound(outputname, header);

   int i, channel;
   double newsample;
   for (i=0; i<insound.getSamples(); i++) {
      insound.incrementSample();   // starts on zeros first time
      newsample = 0.0;
      for (channel = 0; channel < insound.getChannels(); channel++) {
         newsample += insound.getCurrentSampleDouble(channel);
      }
      outsound.writeSampleDouble(amp * newsample/insound.getChannels());
   }

   return 0;
}




